@@ -35,6 +35,9 @@ class KatRes:
 # --
 # --
 
+  def as_dict(self) -> Dict:
+    return self.raw.to_dict()
+
   @property
   def uid(self):
     return self.raw.metadata.uid
